@@ -80,8 +80,9 @@ class Plotter:
         optimal_max = upper_percentile + pad_amount
 
         return optimal_min, optimal_max
-    
-    def literal_eval(self, config):
+
+    @staticmethod
+    def literal_eval(config):
         """ Evaluate literal string as Python code """
         config['y_var'] = config['y_var'].replace(
             {None: "[]"}).apply(lambda x: ast.literal_eval(x) if '[' in x else x)
@@ -168,24 +169,31 @@ class Plotter:
         else:
             plt.show()
         return
-    
+
+    @staticmethod
+    def __read_config__(config):
+        """ Read CSV and plot all rows """
+        # Read the configuration CSV file
+        if isinstance(config, str) and os.path.exists(config):
+            config = pd.read_csv(config).fillna(
+                'None').replace({float('nan'): None, np.nan: None, 'None': None})
+        else:
+            config = pd.DataFrame(config)
+
+        # Convert columns to Python objects
+        config = Plotter.literal_eval(config)
+        return config
+
     def plot_from_csv(self, config, data=None,
                       theme='default', palette='viridis', aspect='big', 
                       save_folder=None, multi_process=False, **kwargs):
         """ Read CSV and plot all rows """
         # Read the configuration CSV file
-        if isinstance(config, str) and os.path.exists(config):
-            config_df = pd.read_csv(config).fillna(
-                'None').replace({float('nan'): None, 'None': None})
-        else:
-            config_df = pd.DataFrame(config)
-
-        # Convert columns to Python objects
-        config_df = self.literal_eval(config_df)
+        config = Plotter.__read_config__(config)
 
         # Prepare the list of jobs for multi-processing
         jobs = []
-        for index, row in config_df.iterrows():
+        for index, row in config.iterrows():
             config = row.to_dict()  # Convert row to dictionary
             file_name = config.pop('savn', None)
             config.update(dict(theme=theme, palette=palette, aspect=aspect))
